==> cresce_ui-0.8.6.tar.gz: lib/src/c_data_table.dart <==
part of cresce_ui;

class CDataTable extends StatelessWidget {
  final List<CTableColumn> columns;
  final List<CTableRow> rows;
  final void Function(CTableRow row)? onTap;
  final double? height;

  const CDataTable({
    Key? key,
    required this.columns,
    required this.rows,
    this.height = 500.0,
    this.onTap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: columns
              .map((e) => Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 3.0),
                    child: CPageTitle(title: e.label, width: e.width),
                  ))
              .toList(),
        ),
        SizedBox(
          height: height,
          child: Theme(
            data: Theme.of(context).copyWith(dividerColor: Colors.transparent),
            child: ListView(
              children: _mapRows(),
            ),
          ),
        ),
      ],
    );
  }

  List<Widget> _mapRows() => rows
      .map(
        (row) => GestureDetector(
          onTap: () => onTap?.call(row),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: _mapDataToCells(row),
          ),
        ),
      )
      .toList();

  List<Widget> _mapDataToCells(CTableRow row) {
    List<Widget> cells = [];

    for (var i = 0; i < row.data.length; ++i) {
      cells.add(
        Padding(
          padding: const EdgeInsets.symmetric(vertical: 3),
          child: CText(
            label: row.data[i],
            style: CTextStyles.fieldSecondaryVar1,
            width: columns[i].width,
            align: columns[i].dataAlign,
          ),
        ),
      );
    }

    return cells;
  }
}

class CTableRow {
  final List<String> data;
  final List<String>? metadata;

  CTableRow(this.data, {this.metadata});
}

class CTableColumn {
  final String label;
  final double width;
  final TextAlign? dataAlign;

  CTableColumn({
    required this.label,
    required this.width,
    this.dataAlign,
  });
}

==> cresce_ui-0.8.14.tar.gz: lib/src/c_data_table.dart <==
part of cresce_ui;

class CDataTable extends StatelessWidget {
  final List<CTableColumn> columns;
  final List<CTableRow> rows;
  final void Function(CTableRow row)? onTap;
  final double? height;

  const CDataTable({
    Key? key,
    required this.columns,
    required this.rows,
    this.height = 500.0,
    this.onTap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: columns
              .map((e) => Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 3.0),
                    child: CPageTitle(title: e.label, width: e.width),
                  ))
              .toList(),
        ),
        SizedBox(
          height: height,
          child: Theme(
            data: Theme.of(context).copyWith(dividerColor: Colors.transparent),
            child: ListView(
              children: _mapRows(),
            ),
          ),
        ),
      ],
    );
  }

  List<Widget> _mapRows() => rows
      .map(
        (row) => GestureDetector(
          onTap: () => onTap?.call(row),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: _mapDataToCells(row),
          ),
        ),
      )
      .toList();

  List<Widget> _mapDataToCells(CTableRow row) {
    List<Widget> cells = [];

    for (var i = 0; i < row.data.length; ++i) {
      cells.add(
        Padding(
          padding: const EdgeInsets.symmetric(vertical: 3),
          child: CText(
            label: row.data[i],
            style: CTextStyles.fieldSecondaryVar1,
            width: columns[i].width,
            align: columns[i].dataAlign,
          ),
        ),
      );
    }

    return cells;
  }
}

class CTableRow {
  final List<String> data;
  final List<String>? metadata;

  const CTableRow(this.data, {this.metadata});
}

class CTableColumn {
  final String label;
  final double width;
  final TextAlign? dataAlign;

  const CTableColumn({
    required this.label,
    required this.width,
    this.dataAlign,
  });
}
